@@ -3,7 +3,7 @@ import execute_fb_tests
 import fb_update
 
 def cli_run():
-    execute_fb_tests.main(sys.argv[1:])
+    execute_fb_tests.cli(sys.argv[1:])
 
 def cli_update():
-    fb_update.main(sys.argv[1:])
\ No newline at end of file
+    fb_update.main(sys.argv[1:])
