@@ -53,18 +53,19 @@ else:
 class FBWrapper:
     def __init__(self, **kwargs):
         # Initialization
-        self.binary = kwargs["binary"]
-        self.profile = kwargs["profile"]
-        self.serverpath = kwargs["serverpath"]
-        self.version = kwargs["version"]
-        self.couchURI = kwargs["couchURI"]
-        self.databasename = kwargs["databasename"]
-        self.testlist = kwargs["testlist"]
-        self.waitTime = kwargs["waitTime"]
+        self.binary = kwargs.get("binary")
+        self.profile = kwargs.get("profile")
+        self.serverpath = kwargs.get("serverpath")
+        self.version = kwargs.get("version")
+        self.couchURI = kwargs.get("couchURI")
+        self.databasename = kwargs.get("databasename")
+        self.testlist = kwargs.get("testlist")
+        self.waitTime = kwargs.get("waitTime")
+        self.debug = kwargs.get("debug")
         self.platform = platform.system().lower()
         
         self.tempdir = tempfile.gettempdir();                               # Temporary directory to store tinderbox builds and temporary profiles                          
-        self.serverpath += ("" if self.serverpath[-1] == "/" else "/")      # Ensure serverpath has correct format
+        self.serverpath = self.serverpath.rstrip("/") + "/"                 # Ensure serverpath has correct format
         self.changeset = {}                                                 # Map to keep track of the last changeset of each build that was run (to prevent running twice on the same changeset)
     
     def clean_temp_folder(self, build=False):
@@ -90,6 +91,8 @@ class FBWrapper:
         Return True if the tests have never been run against the current changeset of 'build'
         Return False otherwise
         """
+        if self.platform == 'darwin':
+            buildpath = os.path.join(buildpath, 'Contents', 'MacOS')
         # Find new changeset
         new_changeset = utils.get_changeset(buildpath)
         if not (version, build) in self.changeset:
@@ -114,6 +117,10 @@ class FBWrapper:
         """
         # For each version of Firefox, see if there is a new changeset and run the tests
         for build in builds:
+            # put this here because the firebug team sometimes forgets and puts 'mozilla-central' instead of central
+            if build.lower() == "mozilla-central":
+                build = "central";
+
             print "[Info] Running Firebug" + version + " tests against Mozilla " + build
 
             # Scrape for the latest tinderbox build and extract it to the basedir
@@ -137,7 +144,7 @@ class FBWrapper:
                             appName = appFile
                             break
                     subprocess.call("cp -r " + os.path.join(appDir, appName) + " " + buildPath, shell=True)
-                    subprocess.call("hdiutil unmount " + appDir, shell=True)
+                    subprocess.call("hdiutil detach " + appDir, shell=True)
                     buildPath = os.path.join(buildPath, appName)
                 else:
                     if self.platform == "windows":
@@ -159,7 +166,10 @@ class FBWrapper:
                     self.binary = buildPath
                 else:
                     self.binary = os.path.join(buildPath, "firefox" + (".exe" if self.platform == "windows" else ""))
-                self.start_tests(version)
+                try:
+                    self.start_tests(version)
+                except Exception, e:
+                    print "[Error] Running Firebug" + version + " against Mozilla " + build + " failed"
                 self.binary = None
             else:
                 print "[Info] Tests already run with this changeset"
@@ -197,16 +207,16 @@ class FBWrapper:
                         # Run the build(s)
                         if not self.binary:
                             ret = self.prepare_builds(version, builds)
+                            if ret != 0:
+                                print ret
                         else:
                 		    self.start_tests(version)
                 		    
                         self.clean_temp_folder()
                 		    
-                        if ret != 0:
-                            print ret
-            except Exception as e:
+            except Exception, e:
         	    print "[Error] Could not run the FBTests"
-        	    raise(e)
+        	    raise
             		
             
             if not self.waitTime:
@@ -252,10 +262,14 @@ def cli(argv=sys.argv[1:]):
                       
     parser.add_option("--interval", dest="waitTime",
                       help="Number of hours to wait between test runs. If unspecified tests are only run once")
+    
+    parser.add_option("--debug", dest="debug",
+                      action="store_true",
+                      help="Enable debug logging")
     (opt, remainder) = parser.parse_args(argv)
     
     wrapper = FBWrapper(binary=opt.binary, profile=opt.profile, serverpath=opt.serverpath, version=opt.version, 
-                                    couchURI=opt.couchURI, databasename=opt.databasename, testlist=opt.testlist, waitTime=opt.waitTime)
+                        couchURI=opt.couchURI, databasename=opt.databasename, testlist=opt.testlist, waitTime=opt.waitTime, debug=opt.debug)
     wrapper.run()
    
 if __name__ == '__main__':
